package com.prolog.rdc.tms.app.service;

import com.prolog.rdc.tms.app.model.dto.*;
import com.prolog.rdc.tms.app.model.vo.*;

import java.util.List;

public interface QueryReportService {

    DeliveryOrderQueryReesponseDTO deliveryOrderQuery(DeliveryOrderQueryVO deliveryOrderQueryVO) throws  Exception;

    DispatchOrderQueryResponseDTO dispatchOrderQuery(DispatchOrderQueryVO dispatchOrderQueryVO) throws  Exception;

    List<DispatchOrderDetailQueryDTO> dispatchOrderDetailQuery(DispatchOrderDetailQueryVO dispatchOrderDetailQueryVO) throws  Exception;

    DriverInformationQueryDTO driverInformationQuery(DriverInformationQueryVO driverInformationQueryVO) throws  Exception;

    List<DriverGetNumberQueryDTO> driverGetNumberQuery(DriverGetNumberQueryVO driverGetNumberQueryVO) throws Exception;

    List<DriverVehicleDTO>  driverVehicleQuery(DriverVehicleQueryVO driverVehicleQueryVO) throws Exception;
}
